import { APIGatewayProxyEvent, Context } from 'aws-lambda';
export interface RouterInterface {
    addResources: (resources: Resource[]) => void;
    route: (request: APIGatewayProxyEvent, context: Context) => Promise<Response>;
}
export interface Resource {
    path: string;
    get?: (event: Event, context: any) => Promise<any>;
    post?: (event: Event, context: any) => Promise<any>;
    put?: (event: Event, context: any) => Promise<any>;
    delete?: (event: Event, context: any) => Promise<any>;
}
export interface Event {
    queryStringParameters: Record<string, string>;
    pathParameters: Record<string, string>;
    headers: Record<string, string>;
    rawBody: string;
}
export interface Response {
    isOk: boolean;
    endpoint: string;
    uri: string;
    response: {
        statusCode: number;
        body: string;
        headers: Record<string, string>;
    };
}
